@@ -14,25 +14,25 @@
 /* ecbuild info */
 
 #ifndef ECBUILD_VERSION_STR
-#define ECBUILD_VERSION_STR "3.6.1"
+#define ECBUILD_VERSION_STR "3.6.3"
 #endif
 #ifndef ECBUILD_VERSION
-#define ECBUILD_VERSION "3.6.1"
+#define ECBUILD_VERSION "3.6.3"
 #endif
 #ifndef ECBUILD_MACROS_DIR
-#define ECBUILD_MACROS_DIR  "/pub/devel/eccodes/eccodes-2.21.0-1.i686/src/eccodes-2.21.0-Source/cmake"
+#define ECBUILD_MACROS_DIR  "/pub/devel/eccodes/eccodes-2.23.0-1.x86_64/src/eccodes-2.23.0-Source/cmake"
 #endif
 
 /* config info */
 
 #define ECCODES_OS_NAME          "CYGWIN-3.2.0(0.340/5/3)"
-#define ECCODES_OS_BITS          32
-#define ECCODES_OS_BITS_STR      "32"
-#define ECCODES_OS_STR           "UNKNOWN.32"
+#define ECCODES_OS_BITS          64
+#define ECCODES_OS_BITS_STR      "64"
+#define ECCODES_OS_STR           "UNKNOWN.64"
 #define ECCODES_OS_VERSION       "3.2.0(0.340/5/3)"
-#define ECCODES_SYS_PROCESSOR    "i686"
+#define ECCODES_SYS_PROCESSOR    "x86_64"
 
-#define ECCODES_BUILD_TIMESTAMP  "20210424215858"
+#define ECCODES_BUILD_TIMESTAMP  "20210930113151"
 #define ECCODES_BUILD_TYPE       "RelWithDebInfo"
 
 #define ECCODES_C_COMPILER_ID      "GNU"
@@ -42,7 +42,7 @@
 #define ECCODES_CXX_COMPILER_VERSION ""
 
 #define ECCODES_C_COMPILER       "/usr/bin/gcc.exe"
-#define ECCODES_C_FLAGS          "-ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/pub/devel/eccodes/eccodes-2.21.0-1.i686/build=/usr/src/debug/eccodes-2.21.0-1 -fdebug-prefix-map=/pub/devel/eccodes/eccodes-2.21.0-1.i686/src/eccodes-2.21.0-Source=/usr/src/debug/eccodes-2.21.0-1 -pipe -O2 -g -DNDEBUG"
+#define ECCODES_C_FLAGS          "-ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/pub/devel/eccodes/eccodes-2.23.0-1.x86_64/build=/usr/src/debug/eccodes-2.23.0-1 -fdebug-prefix-map=/pub/devel/eccodes/eccodes-2.23.0-1.x86_64/src/eccodes-2.23.0-Source=/usr/src/debug/eccodes-2.23.0-1 -pipe -O2 -g -DNDEBUG"
 
 #define ECCODES_CXX_COMPILER     "/usr/bin/g++.exe"
 #define ECCODES_CXX_FLAGS        ""
@@ -54,8 +54,8 @@
 #define ECCODES_INSTALL_LIB_DIR   "/usr/lib"
 #define ECCODES_INSTALL_DATA_DIR  "/usr/share/eccodes"
 
-#define ECCODES_DEVELOPER_SRC_DIR "/pub/devel/eccodes/eccodes-2.21.0-1.i686/src/eccodes-2.21.0-Source"
-#define ECCODES_DEVELOPER_BIN_DIR "/pub/devel/eccodes/eccodes-2.21.0-1.i686/build"
+#define ECCODES_DEVELOPER_SRC_DIR "/pub/devel/eccodes/eccodes-2.23.0-1.x86_64/src/eccodes-2.23.0-Source"
+#define ECCODES_DEVELOPER_BIN_DIR "/pub/devel/eccodes/eccodes-2.23.0-1.x86_64/build"
 
 /* Fortran support */
 
@@ -65,7 +65,7 @@
 #define ECCODES_Fortran_COMPILER_VERSION "10.2.0"
 
 #define ECCODES_Fortran_COMPILER "/usr/bin/gfortran.exe"
-#define ECCODES_Fortran_FLAGS    "-ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/pub/devel/eccodes/eccodes-2.21.0-1.i686/build=/usr/src/debug/eccodes-2.21.0-1 -fdebug-prefix-map=/pub/devel/eccodes/eccodes-2.21.0-1.i686/src/eccodes-2.21.0-Source=/usr/src/debug/eccodes-2.21.0-1 -O2 -g -DNDEBUG"
+#define ECCODES_Fortran_FLAGS    "-ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/pub/devel/eccodes/eccodes-2.23.0-1.x86_64/build=/usr/src/debug/eccodes-2.23.0-1 -fdebug-prefix-map=/pub/devel/eccodes/eccodes-2.23.0-1.x86_64/src/eccodes-2.23.0-Source=/usr/src/debug/eccodes-2.23.0-1 -O2 -g -DNDEBUG"
 
 #endif
 
